@@ -12,7 +12,7 @@ Example:
 >>> test1.delete()  # dangerous!
 '''
 
-__version__      = '0.3'
+__version__      = '0.4'
 __author__       = 'Volker Grabsch'
 __author_email__ = 'vog@notjusthosting.com'
 __url__          = 'http://www.profv.de/python-vserver/'
@@ -544,7 +544,8 @@ class HostingVServer(object):
     def install_webserver(self, default_site):
         self.p.install(
             u'awstats', u'libgeo-ipfree-perl',
-            u'apache2-mpm-itk', u'libapache2-mod-fcgid', u'libapache2-svn', 'libapache2-mod-php5',
+            u'apache2-mpm-itk',
+            u'libapache2-mod-fcgid', 'libapache2-mod-php5', u'libapache2-svn', u'libapache2-mod-wsgi',
             u'php5-cgi', u'php5-cli', u'php5-curl', u'php5-gd', u'php5-imagick', u'php5-imap',
             u'php5-json', u'php5-ldap', u'php5-mcrypt', u'php5-mhash', u'php5-mysql', u'php5-pgsql',
             u'php-imlib', u'php-mail-mime', u'php-soap', u'libphp-jpgraph', u'libphp-phplot',
@@ -587,6 +588,11 @@ class HostingVServer(object):
             u'    IPCCommTimeout 30\n'
             u'</IfModule>\n'
         )
+        self.p.p.write(u'/etc/apache2/mods-available/wsgi.conf', 0644,
+            u'<IfModule mod_wsgi.c>\n'
+            u'    AddHandler wsgi-script .wsgi\n'
+            u'</IfModule>\n'
+        )
         self.p.p.write(u'/etc/php5/conf.d/local_settings.ini', 0644,
             u'memory_limit = 256M\n'
         )
